Index: src/sas/simulation/pointsmodelpy/pointsmodelpymodule/Make.mm
===================================================================
--- src/sas/simulation/pointsmodelpy/pointsmodelpymodule/Make.mm	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/simulation/pointsmodelpy/pointsmodelpymodule/Make.mm	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -12,5 +12,5 @@
 #
 
-PROJECT = SANSsimulation
+PROJECT = SASsimulation
 PACKAGE = pointsmodelpymodule
 MODULE = pointsmodelpy
Index: src/sas/simulation/pointsmodelpy/tests/testcomplexmodel.py
===================================================================
--- src/sas/simulation/pointsmodelpy/tests/testcomplexmodel.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/simulation/pointsmodelpy/tests/testcomplexmodel.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -1,5 +1,5 @@
-from sansModeling.pointsmodelpy import pointsmodelpy
-from sansModeling.iqPy import iqPy
-from sansModeling.geoshapespy import geoshapespy
+from sasModeling.pointsmodelpy import pointsmodelpy
+from sasModeling.iqPy import iqPy
+from sasModeling.geoshapespy import geoshapespy
 
 #First testing: a normal case, a lores model holds a sphere
Index: src/sas/simulation/pointsmodelpy/tests/testnegativepr.py
===================================================================
--- src/sas/simulation/pointsmodelpy/tests/testnegativepr.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/simulation/pointsmodelpy/tests/testnegativepr.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -1,6 +1,6 @@
 if __name__ == "__main__":
-  from sansModeling.pointsmodelpy import pointsmodelpy
-  from sansModeling.iqPy import iqPy
-  from sansModeling.geoshapespy import geoshapespy
+  from sasModeling.pointsmodelpy import pointsmodelpy
+  from sasModeling.iqPy import iqPy
+  from sasModeling.geoshapespy import geoshapespy
 
   a = geoshapespy.new_sphere(10)

Index: src/sas/simulation/pointsmodelpy/libpointsmodelpy/points_model.h
===================================================================
--- src/sas/simulation/pointsmodelpy/libpointsmodelpy/points_model.h	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/simulation/pointsmodelpy/libpointsmodelpy/points_model.h	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -1,3 +1,3 @@
 /** \file points_model.h child class of SANSmodel*/
 
 #ifndef POINTSMODEL_H
@@ -9,9 +9,9 @@
 #include "Point3D.h"
 #include "iq.h"
-#include "sans_model.h"
+#include "sas_model.h"
 
 using namespace std;
 
-class PointsModel : public SANSModel{
+class PointsModel : public SASModel{
  public:
   PointsModel();
@@ -1,3 +1,3 @@
-/** \file points_model.h child class of SANSmodel*/
+/** \file points_model.h child class of SASmodel*/
 
 #ifndef POINTSMODEL_H
Index: src/sas/simulation/pointsmodelpy/tests/testlores.py
===================================================================
--- src/sas/simulation/pointsmodelpy/tests/testlores.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/simulation/pointsmodelpy/tests/testlores.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -1,8 +1,8 @@
 if __name__ == "__main__":
 
-    from sansModeling.iqPy import iqPy
-    #from sansModeling.analmodelpy import analmodelpy as analmodelpymodule
-    from sansModeling.geoshapespy import geoshapespy
-    from sansModeling.pointsmodelpy import pointsmodelpy
+    from sasModeling.iqPy import iqPy
+    #from sasModeling.analmodelpy import analmodelpy as analmodelpymodule
+    from sasModeling.geoshapespy import geoshapespy
+    from sasModeling.pointsmodelpy import pointsmodelpy
 
 #    print "copyright information:"
Index: src/sas/simulation/pointsmodelpy/tests/testlores2d.py
===================================================================
--- src/sas/simulation/pointsmodelpy/tests/testlores2d.py	(revision 794922220f2fb3b23dd08c648aabf87b4850596c)
+++ src/sas/simulation/pointsmodelpy/tests/testlores2d.py	(revision b9a5f0eb8e8cbff8f8d934bbfa4ea18168141e13)
@@ -1,6 +1,6 @@
 def test_lores2d(phi):
-  from sansModeling.pointsmodelpy import pointsmodelpy 
-  from sansModeling.iqPy import iqPy
-  from sansModeling.geoshapespy import geoshapespy
+  from sasModeling.pointsmodelpy import pointsmodelpy 
+  from sasModeling.iqPy import iqPy
+  from sasModeling.geoshapespy import geoshapespy
 
   #lores model is to hold several geometric objects
@@ -15,5 +15,5 @@
   pointsmodelpy.lores_add(lm,c,3.0)
 
   #retrieve the points from lores model for sans calculation
   vp = pointsmodelpy.new_point3dvec()
   pointsmodelpy.get_lorespoints(lm,vp)
@@ -30,7 +30,7 @@
   from Numeric import arange,zeros
   from enthought.util.numerix import Float,zeros
-  from sansModeling.file2array import readfile2array
-  from sansModeling.pointsmodelpy import pointsmodelpy
-  from sansModeling.geoshapespy import geoshapespy
+  from sasModeling.file2array import readfile2array
+  from sasModeling.pointsmodelpy import pointsmodelpy
+  from sasModeling.geoshapespy import geoshapespy
 
   lm = pointsmodelpy.new_loresmodel(0.1)
@@ -70,7 +70,7 @@
   from Numeric import arange,zeros
   from enthought.util.numerix import Float,zeros
-  from sansModeling.file2array import readfile2array
-  from sansModeling.pointsmodelpy import pointsmodelpy
-  from sansModeling.geoshapespy import geoshapespy
+  from sasModeling.file2array import readfile2array
+  from sasModeling.pointsmodelpy import pointsmodelpy
+  from sasModeling.geoshapespy import geoshapespy
 
   lm = pointsmodelpy.new_loresmodel(0.1)
@@ -15,5 +15,5 @@
   pointsmodelpy.lores_add(lm,c,3.0)
 
-  #retrieve the points from lores model for sans calculation
+  #retrieve the points from lores model for sas calculation
   vp = pointsmodelpy.new_point3dvec()
   pointsmodelpy.get_lorespoints(lm,vp)